@@ -1687,8 +1687,16 @@ def checkDigestFile(digestfile):
     return result
 
 
-def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False):
+def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False,
+    with_lxc=False):
     """List run program"""
+    def get_mnt(pid):
+        try:
+            return os.readlink("/proc/%s/ns/mnt" %pid).strip()
+        except Exception:
+            return ""
+
+    main_mnt = get_mnt("1")
 
     def getCmd(procNum):
         cmdLineFile = '/proc/%s/cmdline' % procNum
@@ -1698,6 +1706,9 @@ def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False):
                 if fstat.st_uid != uid:
                     return ""
             if path.exists(cmdLineFile):
+                if not with_lxc:
+                    if get_mnt(procNum) != main_mnt:
+                        return ""
                 if not_chroot:
                     root_link = '/proc/%s/root' % procNum
                     if os.readlink(root_link) != "/":
@@ -1723,5 +1734,3 @@ def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False):
                       map(getCmd,
                           filter(lambda x: x.isdigit(),
                                  listDirectory('/proc'))))
-
-
